package edu.columbia.sip.buddy;

import edu.columbia.sip.AvailabilityEvent;
import edu.columbia.sip.AvailabilityListener;
import edu.columbia.sip.SIPURL;
import edu.columbia.sip.SIPServer;

import java.awt.Label;

import java.util.StringTokenizer;


public class Buddy extends Label implements AvailabilityListener {
    private String _name;
    private String _nick;
    
    /** the URL of the person this buddy represents. */
    private SIPURL _sipurl;

    private String _server;
    private boolean _isActive;
    
    // references to the application's data so that the Buddy can be 
    // responsable for maintaining its own state (here or gone) and for
    // adding itself to the active list (and deleting itself from it)
    // when appropriate.
    private SIPServer _uagent;
    private BuddyList _activeList;
    
    public Buddy(String nick) {
        super(nick);
        _nick = nick;
        _uagent = BuddyListApp.getServer();
        _activeList = BuddyListApp.getActiveList();
        _isActive = false;
        // this is just a default and should be replaced with a way to actually
        // provide the home of this user.
        _sipurl = new SIPURL("sip:" + nick + "@127.0.0.1");
//        listen();
    }
    
    public String toString() {
        return _nick;
    }
    
    public void setName(String name) {
        _name = name;
    }
    
    public String getName() {
        return _name;
    }
    
    public void setNick(String nick) {
        _nick = nick;
        setText(nick);
    }
    
    public String getNick() {
        return _nick;
    }
    
    public void setSIPURL(SIPURL url) {
        _sipurl = url;
    }
    
    public void setSIPURL(String s) {
        _sipurl = new SIPURL(s);
    }
    
    public SIPURL getSIPURL() {
        return _sipurl;
    }
    
    public void setSIPServer(String s) {
        _server = s;
    }
    
    public String getSIPServer() {
        return _server;
    }
    
    /** method from the AvailabilityListener interface - 
     * called when the person this buddy represents is available.
     */
    public void here(AvailabilityEvent ae) {
        System.out.println("Buddy received 'here'...");
        if (!_isActive) {
            System.out.println("Buddy readding to active list...");
            _isActive = true;
            _activeList.add(this);
        } else {
            System.out.println("Buddy not readding to active list, already active.");
        }
    }
    
    /** method from the AvailabilityListener interface -
     * called when the person this buddy represents is no longer available.
     */
    public void gone(AvailabilityEvent ae) {
        if (_isActive) {
            _isActive = false;
            int pos = _activeList.indexOf(this);
            _activeList.remove(pos);
        }
    }
    
    /** method from the AvailabilityListener interface -
     * called if the person this buddy represents is unknown by SIP.
     */
    public void unknown(AvailabilityEvent ae) {
        gone(ae);
    }
    
    public SIPURL getURL() {
        return getSIPURL();
    }
    
    public void listen() {
        _uagent.addAvailabilityListener(this);
    }
    
    public void dontListen() {
        _uagent.removeAvailabilityListener(this);
    }
}
